import { Story, Canvas, Meta, Description } from "@storybook/addon-docs/blocks";
import { withKnobs, text } from "@storybook/addon-knobs";
import { html } from "lit-html";
import CATEGORIES from "../categories";

<Meta title={CATEGORIES.STATIC + "Forms"} />

# Forms

This shows all static form elements currently implemented.

## Labels

A label is used to describe input elements

<Canvas
    mdxSource={`
    <label class="ui-label">Label</label>
`}
>
    <Story name="Label">{html` <label class="ui-label">Label</label> `}</Story>
</Canvas>

Example with input:

<Canvas
    mdxSource={`
    <label for="input1" class="ui-label">Label</label>
    <input id="input1" class="ui-input" placeholder="Placeholder Text"/>
`}
>
    <Story name="Label with input">
        {html`
            <label for="input1" class="ui-label">Label</label>
            <input
                id="input1"
                class="ui-input"
                placeholder="Placeholder Text"
            />
        `}
    </Story>
</Canvas>

## Inputs

This style can be used for most standard input element types like `text`, `number`, `email` etc.

<Canvas
    mdxSource={`
    <input class="ui-input" placeholder="Placeholder Text"/>
`}
>
    <Story name="Input">
        {html` <input class="ui-input" placeholder="Placeholder Text" /> `}
    </Story>
</Canvas>

### Select

<Canvas
    mdxSource={`
    <div class="ui-select">
        <ui-icon class="ui-select__icon" name="arrow-down"></ui-icon>
        <select class="ui-select__select" placeholder="Placeholder Text">
            <option name="option1" value="option1">Option 1</option>
            <option name="option2" value="option2">Option 2</option>
        </select>
    </div>
`}
>
    <Story name="Select">
        {html`
            <div class="ui-select">
                <ui-icon class="ui-select__icon" name="arrow-down"></ui-icon>
                <select
                    class="ui-select__select"
                    placeholder="Placeholder Text"
                >
                    <option name="option1" value="option1">Option 1</option>
                    <option name="option2" value="option2">Option 2</option>
                </select>
            </div>
        `}
    </Story>
</Canvas>
